==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/CancellingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancellingMultiScaleImageEventArgsDescription } from "./CancellingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
export let CancellingMultiScaleImageEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CancellingMultiScaleImageEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CancellingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
                CancellingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CancellingMultiScaleImageEventArgsDescriptionMetadata.c(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
            }
            if (a.k(CancellingMultiScaleImageEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Uri", "String");
        }
        static d(a) {
            CancellingMultiScaleImageEventArgsDescriptionMetadata.b(a);
            a.ad("CancellingMultiScaleImageEventArgs", () => new CancellingMultiScaleImageEventArgsDescription());
            a.ac("CancellingMultiScaleImageEventArgs", CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
    }
    CancellingMultiScaleImageEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CancellingMultiScaleImageEventArgsDescriptionMetadata, 'CancellingMultiScaleImageEventArgsDescriptionMetadata');
    CancellingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return CancellingMultiScaleImageEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/CancellingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancellingMultiScaleImageEventArgsDescription } from "./CancellingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
export let CancellingMultiScaleImageEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CancellingMultiScaleImageEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CancellingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
                CancellingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CancellingMultiScaleImageEventArgsDescriptionMetadata.c(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
            }
            if (a.k(CancellingMultiScaleImageEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Uri", "String");
        }
        static d(a) {
            CancellingMultiScaleImageEventArgsDescriptionMetadata.b(a);
            a.ae("CancellingMultiScaleImageEventArgs", () => new CancellingMultiScaleImageEventArgsDescription());
            a.ad("CancellingMultiScaleImageEventArgs", CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
    }
    CancellingMultiScaleImageEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CancellingMultiScaleImageEventArgsDescriptionMetadata, 'CancellingMultiScaleImageEventArgsDescriptionMetadata');
    CancellingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return CancellingMultiScaleImageEventArgsDescriptionMetadata;
})();
